@@ -10,7 +10,7 @@ from decimal import Decimal
 
 import proteus.config
 
-__version__ = "7.0.2"
+__version__ = "7.0.3"
 __all__ = ['Model', 'Wizard', 'Report']
 
 _MODELS = threading.local()
@@ -1234,6 +1234,10 @@ class Wizard(object):
                 ctx['active_id'] = self.models[0].id
                 ctx['active_ids'] = [model.id for model in self.models]
                 ctx['active_model'] = self.models[0].__class__.__name__
+            elif isinstance(self.models, ModelList):
+                ctx['active_id'] = None
+                ctx['active_ids'] = None
+                ctx['active_model'] = self.models.model_name
             else:
                 ctx['active_id'] = None
                 ctx['active_ids'] = None
