@@ -1,12 +1,20 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
-from unittest import TestCase
-from proteus import config, Report, Model
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
+import unittest
+
+try:
+    import pydot
+except ImportError:
+    pydot = None
+
+from proteus import Model, Report
+
 from .common import ProteusTestCase
 
 
 class TestReport(ProteusTestCase):
 
+    @unittest.skipIf(not pydot, 'requires pydot')
     def test_model_graph(self):
         IrModel = Model.get('ir.model')
         models = IrModel.find([])
